@@ -25,7 +25,7 @@ def create(pname):
         print("Project {} already exists in {}.\n".format(pname, current_path))
         sys.exit()
     else:
-        venv.create(pname, with_pip=True)
+        venv.create(pname)
         os.chdir(exist_path)
         for i in range(len(dirs_folders)):
             os.makedirs(os.path.join(exist_path, dirs_folders[i]))
